#
# spec file for package perl-Perl-Critic
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Perl-Critic
Name:           perl-Perl-Critic
Version:        1.150
Release:        bp156.1.1
License:        Artistic-1.0 OR GPL-1.0-or-later
Summary:        Critique Perl source code for best-practices
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/P/PE/PETDANCE/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(B::Keywords) >= 1.23
BuildRequires:  perl(Config::Tiny) >= 2
BuildRequires:  perl(Exception::Class) >= 1.23
BuildRequires:  perl(Exporter) >= 5.63
BuildRequires:  perl(File::Which)
BuildRequires:  perl(List::SomeUtils) >= 0.55
BuildRequires:  perl(Module::Build) >= 0.420400
BuildRequires:  perl(Module::Pluggable) >= 3.1
BuildRequires:  perl(PPI) >= 1.271
BuildRequires:  perl(PPI::Document) >= 1.271
BuildRequires:  perl(PPI::Document::File) >= 1.271
BuildRequires:  perl(PPI::Node) >= 1.271
BuildRequires:  perl(PPI::Token::Quote::Single) >= 1.271
BuildRequires:  perl(PPI::Token::Whitespace) >= 1.271
BuildRequires:  perl(PPIx::QuoteLike)
BuildRequires:  perl(PPIx::Regexp) >= 0.027
BuildRequires:  perl(PPIx::Regexp::Util) >= 0.068
BuildRequires:  perl(PPIx::Utils::Traversal) >= 0.003
BuildRequires:  perl(Perl::Tidy)
BuildRequires:  perl(Pod::PlainText)
BuildRequires:  perl(Pod::Select)
BuildRequires:  perl(Pod::Spell) >= 1
BuildRequires:  perl(Readonly) >= 2
BuildRequires:  perl(String::Format) >= 1.18
BuildRequires:  perl(Term::ANSIColor) >= 2.02
BuildRequires:  perl(Test::Builder) >= 0.92
BuildRequires:  perl(parent)
BuildRequires:  perl(version) >= 0.77
Requires:       perl(B::Keywords) >= 1.23
Requires:       perl(Config::Tiny) >= 2
Requires:       perl(Exception::Class) >= 1.23
Requires:       perl(Exporter) >= 5.63
Requires:       perl(File::Which)
Requires:       perl(List::SomeUtils) >= 0.55
Requires:       perl(Module::Pluggable) >= 3.1
Requires:       perl(PPI) >= 1.271
Requires:       perl(PPI::Document) >= 1.271
Requires:       perl(PPI::Document::File) >= 1.271
Requires:       perl(PPI::Node) >= 1.271
Requires:       perl(PPI::Token::Quote::Single) >= 1.271
Requires:       perl(PPI::Token::Whitespace) >= 1.271
Requires:       perl(PPIx::QuoteLike)
Requires:       perl(PPIx::Regexp) >= 0.027
Requires:       perl(PPIx::Regexp::Util) >= 0.068
Requires:       perl(PPIx::Utils::Traversal) >= 0.003
Requires:       perl(Perl::Tidy)
Requires:       perl(Pod::PlainText)
Requires:       perl(Pod::Select)
Requires:       perl(Pod::Spell) >= 1
Requires:       perl(Readonly) >= 2
Requires:       perl(String::Format) >= 1.18
Requires:       perl(Term::ANSIColor) >= 2.02
Requires:       perl(Test::Builder) >= 0.92
Requires:       perl(parent)
Requires:       perl(version) >= 0.77
%{perl_requires}

%description
Perl::Critic is an extensible framework for creating and applying coding
standards to Perl source code. Essentially, it is a static source code
analysis engine. Perl::Critic is distributed with a number of
Perl::Critic::Policy modules that attempt to enforce various coding
guidelines. Most Policy modules are based on Damian Conway's book *Perl
Best Practices*. However, Perl::Critic is *not* limited to PBP and will
even support Policies that contradict Conway. You can enable, disable, and
customize those Polices through the Perl::Critic interface. You can also
create new Policy modules that suit your own tastes.

For a command-line interface to Perl::Critic, see the documentation for
perlcritic. If you want to integrate Perl::Critic with your build process,
Test::Perl::Critic provides an interface that is suitable for test
programs. Also, Test::Perl::Critic::Progressive is useful for gradually
applying coding standards to legacy code. For the ultimate convenience (at
the expense of some flexibility) see the criticism pragma.

If you'd like to try Perl::Critic without installing anything, there is a
web-service available at http://perlcritic.com. The web-service does not
yet support all the configuration features that are available in the native
Perl::Critic API, but it should give you a good idea of what it does.

Also, ActivePerl includes a very slick graphical interface to Perl-Critic
called 'perlcritic-gui'. You can get a free community edition of ActivePerl
from http://www.activestate.com.

%prep
%autosetup  -n %{cpan_name}-%{version}

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Build.PL installdirs=vendor
./Build build flags=%{?_smp_mflags}

%check
./Build test

%install
./Build install destdir=%{buildroot} create_packlist=0
%perl_gen_filelist

%files -f %{name}.files
%doc Changes CONTRIBUTING.md examples README README.md
%license LICENSE

%changelog
* Mon Mar  6 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.150
  see /usr/share/doc/packages/perl-Perl-Critic/Changes
  1.150 Sat Mar  4 21:17:45 CST 2023
    [Enhancements]
    Added Test::Builder and Text::Wrap to the list of default exceptions in
    Variables::ProhibitPackageVars. Thanks, Graham Knop. (GH #1025)
    [Internals]
    We now use PPIx::Utils instead of PPIx::Utilities, which is more recently
    maintained.
* Sun Jan  8 2023 Tina Müller <timueller+perl@suse.de>
- updated to 1.148
  see /usr/share/doc/packages/perl-Perl-Critic/Changes
  1.148 Sat Jan  7 15:20:07 CST 2023
    [Possible breakage]
    Removed Perl::Critic::Utils::DataConversion. Any add-on policies that used
    it will need to copy the functions from there into their own code.
    [Documentation]
    ProhibitCascadingIfElse no longer suggests using given/when.
    [Internals]
    We no longer require Test::Deep for testing.
    Test::Kwalitee is now only recommended, not required.
    Random microoptimizations, like using hashes for array contents checking,
    and using any() instead of calling grep as a boolean.
* Fri Dec 23 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.146
  see /usr/share/doc/packages/perl-Perl-Critic/Changes
  1.146 Wed Dec 21 21:05:20 CST 2022
    [New features]
    ProhibitBarewordDirHandles now checks for sysopen as well as open. Thanks,
    Tadeusz Sośnierz. (GH #732)
    Added a Dockerfile in the extras/ directory for those who want to run P::C
    in a container. Thanks, Isaac Gittins. (GH #832)
    Subroutines::ProhibitBuiltinHomonyms now can take an "allows" parameter to
    specify subroutines that won't violate the policy. Thanks, UTAGAWA Kiki.
    (GH #14, #932)
    ProhibitStringyEval now allows package declarations in evals when
    allow_includes = true. This is a common way packages are declared.
    Thanks, Chris Novakovic. (GH #908)
    [Bug Fixes]
    Fixed some problems with how Perl::Critic determined scope. Thanks, Tom
    Wyant. (GH #793)
    Fixed improper violation for lexical subroutines in
    Subroutines::ProhibitBuiltinHomonyms. Thanks, TOYAMA Nao. (GH #973, #955,
    [#546])
    ValuesAndExpressions::RequireNumberSeparators no longer complains if your
    version numbers do not have number separators in them. Thanks, Tom Wyant.
    (GH #856, #904)
    Fixed a false positive with split() in ProhibitUnusedCapture. Thanks, Tom
    Wyant. (GH #888)
    [Internals]
    We no longer use or need IO::String. Thanks, Graham Knop. (GH #997)
    Removed requirements and mentions of modules no longer used:
  * Fatal
  * IO::String
  * IPC::Open2
  * Pod::Parser
  * Task::Weaken
* Mon Dec 12 2022 Tina Müller <timueller+perl@suse.de>
- updated to 1.144
  see /usr/share/doc/packages/perl-Perl-Critic/Changes
  1.144 Mon Dec  5 09:44:04 PM CST 2022
    Perl::Critic now requires Perl 5.10.1.
    [New features]
    The ProhibitAugmentedAssignmentInDeclaration policy now allows augmented
    assignments to "our" variables, if the allow_our option is enabled.
    Thanks, Graham Knop. (GH #993)
    ProhibitExplicitISA now recommends "use parent" instead of "use base".
    (GH #987)
    RequireUseWarnings now recognizes that "use v5.36" implies warnings.
    Thanks, Andrew Grechkin. (GH #984)
    Subroutines::ProhibitNestedSubs now allows lexical subroutines can
    now be inside of other subroutines. Thanks, TOYAMA Nao. (GH #946,
    [#971], #972)
    RequireUseStrict now knows that Test::Spec enables it. (GH #906)
    ProhibitUnusedCapture now understands @{^CAPTURE} and %%{^CAPTURE_ALL} that
    were added in Perl 5.26.0. Thanks, Tom Wyant. (GH #778)
    Allow numeric operators on special number strings 'NaN' and 'inf'. Thanks,
    Omer Gazit. (GH #803)
    [Fixes]
    Miscellanea::ProhibitUselessNoCritic no longer filters out errors about
    itself, just as Miscellanea::ProhibitUnrestrictedNoCritic cannot. Thanks,
    Bernhard Schmalhofer. (GH #939)
    Fixed GH #878: bareword filehandle dies on `open(CHECK, '/foo');`. Thanks,
    Tom Wyant.
    [Internals]
    Updated to using Perl 5.10.1. Starting migrating to Perl 5.10-isms like
    defined-or. Thanks, James Raspass.
    [Documentation]
    Updated some outdated docs in Perl::Critic::Utils. Thanks, Slaven Rezić.
    (GH #951)
  1.142 Mon Nov 28 08:12:14 PM CST 2022
    This is the last version of Perl::Critic that will run on Perl 5.6.1.  The
    next release will require Perl 5.10.1.
    [New Features]
    Add new policy InputOutput::ProhibitBarewordDirHandles, comparable to
    ProhibitBarewordFilehanles.  Thanks, raf. (GH #912)
    References::ProhibitDoubleSigils policy now allows for Perl's
    postfix dereference syntax and does not report a policy violation.
    Thanks to Ilya Rassadin (GH #578)
    Added Test::Class::Moose and MooseX::MethodAttributes::Role to the
    list of modules that are equivalent to "use strict".  (GH #808, GH #886)
    Subroutines::RequireArgUnpacking now detects anonymous subroutines with
    attributes, prototypes or signatures.  Thanks, Tom Wyant. (GH #684)
    ProhibitVoidMap and ProhibitVoidGrep now detect void context inside subs,
    such as:
    sub { map { foo($_) } @list; return }
    Thanks, James Raspass. (GH #905)
    RequireArgUnpacking now allows a closure to be recognized as a way that
    subroutine arguments can be unpacked.  This is specified with an optional
    allow_closures configuration option.  Thanks, Tom Wyant. (GH #737)
    ProhibitTwoArgOpen now disallows one-arg opens as well. Also, it
    no longer allows two-arg opening of STDIN/STDOUT/STDERR.  Thanks,
    Dan Book. (GH #652, #653)
    [Fixes]
    ProhibitLeadingZeros would not handle sysopen and lexical variables
    correctly. This has been fixed. Thanks, Tom Wyant. (GH #789)
    [Documentation]
    We note that the any() function is available in both List::MoreUtils and
    List::SomeUtils.
    Added instructions to perlcritic on how to integrate with Visual Studio
    Code.  Thanks, sigzero.
    [Internals]
    Switch to using List::SomeUtils instead of List::MoreUtils.
* Thu Oct  6 2022 Stephan Kulow <coolo@suse.com>
- Add 3 more Pod::* requires to make it build (and reverse dependencies).
  Not sure where they were hidden before, but now they are required
  on Tumbleweed
* Thu Mar 25 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.140
  see /usr/share/doc/packages/perl-Perl-Critic/Changes
  1.140 Tue Mar 23 21:42:19 CDT 2021
    [New Features]
    Subroutines::RequireFinalReturn now lets you specify a
    terminal_methods parameter to specify methods that should been as
    terminal.  This is like the terminal_funcs parameter, but for methods.
    Thanks, Robin Smidsrød and Mike Bruins. (GH #920)
  1.139_01 Tue Sep  1 23:52:18 CDT 2020
    [Fixes]
    Removed an extra /x in RequireInterpolationOfMetachars.pm that caused
    deprecation warnings in Perl 5.22 and higher.  (GH #822)
    Documentation::RequirePackageMatchesPodName now recognizes the package
    name if it's in C<< I<> >> or C<< B<> >> markup.  Thanks, Renée Bäcker.
    (GH #913)
* Sat Jan 25 2020 <timueller+perl@suse.de>
- updated to 1.138
  see /usr/share/doc/packages/perl-Perl-Critic/Changes
  1.138 Fri Jan 24 15:50:34 CST 2020
    Stable release.  No changes since 1.137_01.
  1.137_01 Thu Jan 23 16:44:57 CST 2020
    [Fixes]
    RequireCheckingReturnValueOfEval didn't count returning the result of an
    eval as checking it.  Now it does.  However, it's only if you "return eval
    { ... }".  It still doesn't handle the case of "return ( eval {} )".
    Thanks, Tom Wyant. (GH #324)
    ProhibitPunctuationVars would get confused and think that the expression
    qr/SOME$/ was using the $/ special variable.  Thanks, Tom Wyan. (GH #843)
* Thu Nov 28 2019 <timueller+perl@suse.de>
- updated to 1.136
  see /usr/share/doc/packages/perl-Perl-Critic/Changes
  1.136 Wed Nov 27 09:51:09 CST 2019
    Stable release.  No changes since 1.135_01.
  1.135_01 Tue Nov 26 14:50:11 CST 2019
    [New Features]
    The ProhibitNoWarnings pollicy now handles warnings in the experimental::
    group.  Thanks, Renée Bäcker. (GH #892)
    [Documentation]
    Prevented some example code from showing up in `perldoc`.  Thanks, Tom
    Hukins.  (GH #799)
* Thu May 23 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.134
  see /usr/share/doc/packages/perl-Perl-Critic/Changes
  1.134 Wed May 22 21:17:21 CDT 2019
    Stable release.  No changes since 1.133_02.
* Wed Apr  3 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.132
  see /usr/share/doc/packages/perl-Perl-Critic/Changes
  1.32    Thu May 31 21:48:48 CDT 2018
    [New Features]
    Added the ability to specify a regex to tell what unused private
    subroutines are OK in Subroutines::ProhibitUnusedPrivateSubroutines.
    This is handy for Moose classes where there could be many false
    positives on _build_xxxx() subroutines.
    Thanks, Dave Cross.  (GH #811, #812)
    [Dependencies]
    Perl::Critic now no longer relies on the deprecated Email::Address.
    (GH #816)
  1.131_02 Tue Feb 20 17:18:03 CST 2018
    [New Features]
    Perl::Critic now assumes that .psgi files are Perl, too.  Thanks, Tom
    Hukins. (GH#805)
    Variables::ProhibitUnusedVariables no longer gives a false positive for
    variables used in interpolation.  Thanks, Omer Gazit. (GH#801)
    [Bug Fixes]
    Added missing requirement for Fatal.pm.
  1.131_01 Tue Nov 21 17:28:06 CST 2017
    [New Features]
    In the ProhibitLeadingZeros policy, added an exception for mkfifo.
    Thanks, Evan Zacks. (GH#786)
    Add color support for Windows platforms.  Thanks, Roy Ivy III. (GH#700)
    [Bug Fixes]
    Recode Perl::Critic::Utils::all_perl_files() to use File::Find instead
    of opendir/readdir.  This solves endless directory traversals if
    the directories contain circular symbolic references.  Thanks, Tom Wyant.
    [Documentation]
    Added CONTRIBUTING.md.  Thanks, Jonas B. Nielsen.
* Fri Jul 21 2017 coolo@suse.com
- updated to 1.130
  see /usr/share/doc/packages/perl-Perl-Critic/Changes
  1.130   Thu Jul 20 23:16:34 CDT 2017
    [New Features]
  * Policies which ensure that system calls are checked such as
    RequireCheckedSystemCalls now have an "autodie_modules" setting which
    allows you to tell the policy about other modules which export
    autodie. Fixes #699. PR #747. Thanks to Dave Rolsky.
* Wed Jun 14 2017 coolo@suse.com
- updated to 1.128
  see /usr/share/doc/packages/perl-Perl-Critic/Changes
  1.128    Sat Jun 10 22:31:28 CDT 2017
    Official release.  No changes since 1.127_02.
  1.127_02 Tue May 23 18:31:59 CDT 2017
  Developer release leading up to 1.128.
    [Bug Fixes]
  * PPI misparsing a module caused an incorrect "Must end with a
    recognizable true value."  This is fixed by upgrading to PPI
    1.224. (GH #696, GH #607)
  * A test would fail under the upcoming Perl 5.26 that omits the current
    directory from @INC.  Thanks, Kent Fredric.
  * Fixed an invalid test in the RequireBarewordsIncludes test.  Thanks,
    Christian Walde. (GH #751)
  * If an element contained blank lines then the source "%%r" displayed
    for a violation was wrong. Thanks, Sawyer X. (GH #702, #734)
    [Dependencies]
    Perl::Critic now requires PPI 1.224.  PPI is the underlying Perl parser
    on which Perl::Critic is built, and 1.224 introduces many parsing fixes
    such as:
  * Fixes for dot-in-@INC.
  * Parse left side of => as bareword even if it looks like a keyword or op.
  * $::x now works.
  * Higher accuracy when deciding whether certain characters are operators or
    variable type casts (*&%% etc.).
  * Subroutine attributes parsed correctly.
    [Performance Enhancements]
  * Sped up BuiltinFunctions::ProhibitUselessTopic ~7%%.  Thanks, James
    Raspass. (GH #656)
    [Documentation]
  * Fixed incorrect explanation of capture variables in
    ProhibitCaptureWithoutTest.  Thanks, Felipe Gasper.
  * Fixed incorrect links. Thanks, Glenn Fowler.
  * Fixed incorrect example for returning a sorted list.  Thanks, @daviding58.
  * Fixed invalid POD.  Thanks, Jakub Wilk. (GH #735)
  * Updated docs on ProhibitYadaOperator.  Thanks, Stuart A Johnston. (GH #662)
  * Removed all the references to the old mailing list and code repository
    at tigris.org.  (GH #757)
  1.127_01 Sun May 21 21:57:16 CDT 2017
    Removed from CPAN because it did not get indexed correctly.
* Sun Aug 23 2015 coolo@suse.com
- updated to 1.126
  see /usr/share/doc/packages/perl-Perl-Critic/Changes
  1.126 2015-08-10
    [New Policies]
  * Added a policy: ControlStructures::ProhibitYadaOperator - Never use ...
    in production code.
    [Bug Fixes]
  * Fixed problems arising from having -b in your .perltidyrc file. Thanks
    @hjkatz.
  * Removed extra newline from policy names returned by P::C::Config->policies.
    Thanks @ratsbane.
  * `fc` and `say` are now covered by ProhibitUselessTopic. Thanks @JRaspass.
    [Miscellanea]
  * Add more strict/warnings importer modules. Thanks @oalders.
  * Path::Tiny is now recommended over File::Slurp
  * Micro-optimize by calling ->content() directly instead of going
    through the overloads. Thanks @JRaspass.
  * Square brackets are now allowed around your `## no critic` policy
    list. Thanks @zdm.
* Tue Apr 28 2015 coolo@suse.com
- updated to 1.125
  see /usr/share/doc/packages/perl-Perl-Critic/Changes
  1.125 2015-03-02
    [Bug Fixes]
  * Corrected dependency on List::Util::any() to List::MoreUtils::any()
    [Miscellanea]
  * Revised and updated documentation.
  1.124 2015-02-27
    [Policy Changes]
  * The ProhibitUnusedPrivateSubroutines policy can now ignore files that
    use particular modules with 'skip_when_using' option allows of, for
    example, skipping the policy for roles.  Thanks to Mark Fowler.
  * The RequireUseStrict and RequireUseWarnings policies now regard Moose,
    Moo, Mouse, Dancer, Mojolicious, and several other modules as equivalent
    to the strict and warnings pragma.
    [Bug Fixes]
  * The RequireChecked* family of policies has been fixed to accommodate
    version numbers when use-ing the autodie pragma. GH #612. Thanks citrin.
  1.123 2014-11-11
    [Dependencies]
  * Now requires PPI-1.220 which has numerous bug fixes. This may
    eliminate the need for some "## no critic" markers you inserted to
    work around those bugs. The "ProhibitUselessNoCritic" policy should
    help you find them.
    [Miscellanea]
  * Fixed a typo in the Variables::ProhibitPerl4PackageNames message.
* Mon Sep 15 2014 coolo@suse.com
- updated to 1.122
    [Dependencies]
  * Now requires PPI-1.218 which has numerous enahncements and bug fixes.
    Also now requires Readonly-2.00, which obviates the need for Readonly::XS
    to get fast constants.
  * File::HomeDir, File::Which, and Term::ANSIColor are all required now
    instead of being optional or recommended. This simplifies our test code
    and ensures consistent optimal behavior for all users.
    [New Policies]
  * Added two new policies: BuiltinFunctions::ProhibitUselessTopic and
    RegularExpressions::ProhibitUselessTopic.
    [Miscellanea]
  * Updated the perlcritic.el script to use modern Emacs hooks.
    Thanks to @intrigeri and the Debian team for the patch.  Fixes GH #556.
  * Removed all the internal RCS keyword boilerplate blocks that were never
    getting expanded.
* Mon Nov 11 2013 rschweikert@suse.com
- Added new themes based on CERT guidelines.
* Thu Oct 31 2013 rschweikert@suse.com
- update to 1.120
    Bug Fixes:
  * Corrected "Possible precedence issue with control flow operator"
    warning.  This fixes RT #88866
* Mon Sep 30 2013 rschweikert@suse.com
- updated to 1.119
    Bug Fixes:
  * Tests were failing with Config::Tiny 2.17 or later, due to a
    change in the error messages produced by that module.
    This fixes #16 on Github,  #88679 & #88889 on RT.
    Policy Changes:
  * BuiltinFunctions::ProhibitVoidGrep and ::ProhibitVoidMap: grep
    and map called as functions are now allowed in slice operations.
    RT #79289
    Thanks to Wade at Anomaly dot org for the patch.
  * Subroutines::RequireArgUnpacking: Most tests of the size of @_
    are now allowed.  RT #79138
    Other Changes:
  * Modernized our usage of Exporter.  See RT #75300.
    Thanks to Olivier MenguÃ© for the patch.
* Sat Jun  8 2013 rschweikert@suse.com
- updated to 1.118
  Policy Changes:
  * CodeLayout::RequireTidyCode: Revise to work with incompatible
    changes in Perl::Tidy 20120619. RT #77977.
  * TestingAndDebugging::ProhibitNoWarnings: Correct the parse of the
    'no warnings' statement, so that 'no warnings "qw"' is recognized
    as supressing just 'qw' warnings. RT #74647.
  * Miscellanea::RequireRcsKeywords has been moved to the Perl-Critic-More
    distribution,  RT #69546
    Other Changes:
  * Make all unescaped literal "{" characters in regexps into
    character classes. These are deprecated, and became noisy with
    Perl 5.17.0.  RT #77510.
* Tue Feb 14 2012 coolo@suse.com
- updated to 1.117
  New Policies:
  * Variables::ProhibitAugmentedAssignmentInDeclaration reports
    constructs like 'my $x += 1'. Contributed by Mike O'Regan
  Policy Changes:
  * BuiltinFunctions::ProhibitLvalueSubstr: Add explicit 'use version'.
    RT #68498.
  * CodeLayout::ProhibitHardTabs: Add 'pbp' to the default_themes list.
    RT #71093.
  * ControlStructures::ProhibitMutatingListFunctions now understands that
    tr///r (introduced in 5.13.7) does not change its operand.
  * ControlStructures::ProhibitMutatingListFunctions now understands that
    '//=', '<<=', and '>>=' are assignment operators. RT #70901.
  * ErrorHandling::RequireCheckingReturnValueOfEval now allows things
    like grep { eval $_ }. RT #69489.
  * Modules::RequireExplicitPackage now has configuraion option
    allow_import_of, to allow the import of specified modules before
    the package statement. RT #72660.
  * RegularExpressions::ProhibitEnumeratedClasses no longer thinks
    that [A-Za-z_] matches \w. RT #69322.
  * RegularExpressions::ProhibitUnusedCaptures now skips the first
    block of an 'if' or 'elsif' if the regular expression is bound to
    its operand with the '!~' operator. RT #69867.
  * RegularExpressions::ProhibitUnusedCaptures now looks into lists
    and blocks in the replacement portion of the regular expression if
    /e is asserted. RT #72086.
  * RegularExpressions::RequireDotMatchAnything,
    RegularExpressions::RequireExtendedFormatting and
    RegularExpressions::RequireLineBoundaryMatching now honor defaults
    set with 'use re "/modifiers"'. RT #72151.
  * Subroutines::ProhibitManyArgs now recognizes '+' as a prototype
    character.
  * Variables::ProhibitPunctuationVars now recognizes bracketed
    variables embedded in interpolated strings (e.g. "${$}"). For the
    purpose of the 'allow' configuration, these are considered
    equivalent to the unbracketed form. RT #72910.
  Other Changes:
  * Corrected POD in Perl::Critic::PPI::Utils. RT #68898.
  * Perl::Critic::Violation source() method now returns the line
    containing the violation (not the first line) when the statement
    containing the violation spans multiple lines.
* Mon Dec 19 2011 coolo@suse.de
- update to 1.116
    Policy Changes:
  * BuiltInFunctions::ProhibitLvalueSubstr does not report violations
    if the document contains an explicit 'use n.nnn;' where the
    version is before 5.005.  RT #59112
  * Documentation::RequirePodSections no longer blows up on code
    having POD but no =head1. This problem was introduced with RT
    [#59268]. RT #67231
  * RegularExpressions::ProhibitUnusedCapture should more reliably
    find things like s/(a)/${1}2/.  RT #67273.
  * ValuesAndExpressions::ProhibitMagicNumbers and
    Module::RequireVersionVar now treat versions passed as the second
    argument of a 'package' statement the same as versions declared as
    'our $VERSION ...'.  RT #67159
  * Variables::RequireLexicalLoopIterators does not report violations
    if the document contains an explicit 'use n.nnn;' where the
    version is before 5.004.  RT #67760
* Sun Nov  6 2011 rschweikert@suse.com
- Set executable permission for commandline interface (/usr/bin/perlcritic)
* Sat Apr  2 2011 coolo@novell.com
- update to 1.115
  * Fatal error in RegularExpressions::ProhibitUnusedCapture here
    document check.  RT #67116.
  * Internal POD error in Documentation::RequirePodLinksIncludeText.  Patch
    by Salvatore Bonaccorso.  RT #67012
* Thu Mar 31 2011 coolo@novell.com
- update to 1.114
    Policy Changes:
  * Documentation::RequirePodLinksIncludeText now handles nested POD
    formatting. RT #65569
  * Clarified relation of severity numbers to names in Perl::Critic
    POD. RT #66017
  * Removed caveats from Variables::RequireLocalizedPunctuationVars,
    no longer necessary with PPI 1.208. RT #65514
  * Have InputOutput::RequireBriefOpen attempt to expand scope as
    necessary to deal with the case where the open() and the
    corresponding close() are not in the same scope. RT #64437
  * RegularExpressions::ProhibitUnusedCapture now looks inside
    double-quotish things. RT #38942.
  * RegularExpressions::ProhibitUnusedCapture now takes logical
    alternation into account, so that (e.g.)
    if ( /(a)/ || /(b)/ ) {
    say $1;
    }
    is not a violation. RT #38942.
  * ValuesAndExpressions::ProhibitCommaSeparatedStatements now
    recognizes 'return { foo => 1, bar => 2 }' as containing a hash
    constructor, not a block. This was fixed by PPI 1.215. RT #61301.
  * ValuesAndExpressions::ProhibitCommaSeparatedStatements now
    recognizes 'bless { foo => 1, bar => 2 }' as containing a hash
    constructor, not a block. This was fixed by PPI 1.215. RT #64132.
* Wed Dec  1 2010 coolo@novell.com
- switch to perl_requires macro
* Fri Nov 19 2010 chris@computersalat.de
- update to 1.109
  - Bug Fixes:
  * ValuesAndExpressions::RequireInterpolationOfMetachars fix due to changes
    in Email::Address 1.890.  Note that this may find problems in code that
    it didn't before, e.g. q<'@foo'>.
* Thu Jul 15 2010 chris@computersalat.de
- update to 1.108
  o for full list please see Changes file
- recreated by cpanspec 1.78
  o fix deps
- added bcond_with test for
  o Test::Deep
  o Test::Memory::Cycle
- split up old pkg to perl-Perl-Critic_1_106
  o 1.108 builds only on suse_version > 1120
* Wed Jul 14 2010 chris@computersalat.de
- update to 1.106
  * NamingConventions::Capitalization fix for PPI 1.212.  RT #57348
- recreated by cpanspec 1.78
  o fix deps
* Mon Nov 23 2009 rschweikert@novell.com
- Initial build of perlcritic
